Docker Image
=============

Aside from methods in API definition - :class:`conu.apidefs.image.Image`, DockerImage implements following methods:

.. autoclass:: conu.DockerImage
   :members:

.. autoclass:: conu.DockerImagePullPolicy
   :members:

.. autoclass:: conu.DockerImageViaArchiveFS
   :members:

Aside from methods in API definition - :class:`conu.apidefs.image.S2Image`, S2IDockerImage implements following methods:

.. autoclass:: conu.S2IDockerImage
   :members: usage, extend

